summaryrefslogtreecommitdiffstats
path: root/cmd.c
diff options
context:
space:
mode:
authornicm <nicm>2021-08-21 14:06:17 +0000
committernicm <nicm>2021-08-21 14:06:17 +0000
commitc286fbdcd778c0d3d6b60a9f8682b413078e4639 (patch)
tree823a1858cad8172d2e791f241e220138be19b720 /cmd.c
parent110ba767e591946d6784acef87737850f2ad3ae9 (diff)
Preserve command group when moving temporary list to current list being
buit.
Diffstat (limited to 'cmd.c')
-rw-r--r--cmd.c13
1 files changed, 12 insertions, 1 deletions
diff --git a/cmd.c b/cmd.c
index 29f2d130..52c5ad74 100644
--- a/cmd.c
+++ b/cmd.c
@@ -594,7 +594,18 @@ cmd_list_append(struct cmd_list *cmdlist, struct cmd *cmd)
TAILQ_INSERT_TAIL(cmdlist->list, cmd, qentry);
}
-/* Move all commands from one command list to another */
+/* Append all commands from one list to another. */
+void
+cmd_list_append_all(struct cmd_list *cmdlist, struct cmd_list *from)
+{
+ struct cmd *cmd;
+
+ TAILQ_FOREACH(cmd, from->list, qentry)
+ cmd->group = cmdlist->group;
+ TAILQ_CONCAT(cmdlist->list, from->list, qentry);
+}
+
+/* Move all commands from one command list to another. */
void
cmd_list_move(struct cmd_list *cmdlist, struct cmd_list *from)
{